# EasyVCF
Converts contacts' information in csv file

#### Advantages
- Saves a lot of time for user
- Prevents human-made errors Ex. Entering the wrong number

## How To Install
In terminal: `pip install easyvcf` <br>
To run: `easyvcf`

## How To Use
1. Enter csv filename (with .csv extension) which will be converted
![csvfile](https://user-images.githubusercontent.com/73137174/195720541-c4f03af0-72d0-453b-a4be-68f406c8076f.gif)
2. Enter column numbers of contact informations' <br>
![columnnames](https://user-images.githubusercontent.com/73137174/195720685-cc03b92c-e0b0-4e14-81fa-6372eb28d6a8.gif)
3. Enter keyword for contacts (makes easier to find contacts on mobile devices)
![keyword](https://user-images.githubusercontent.com/73137174/195720701-4bc80e20-1fa2-412d-be6e-796755797ed7.gif)
4. Enter new vcf filename (WITHOUT .vcf extension) to export contacts
![tovcf](https://user-images.githubusercontent.com/73137174/195721008-e82ca8cb-4efd-4fe7-aa3a-27408d1f23b7.gif)

## Inspired By
[charlax](https://github.com/charlax/) - [csv2vcard](https://github.com/charlax/csv2vcard)